package com.fs.his.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.his.domain.FsComplaintTemplate;

import java.util.List;

/**
 * 投诉模板Service接口
 *
 * @author fs
 * @date 2025-06-09
 */
public interface IFsComplaintTemplateService extends IService<FsComplaintTemplate>{
    /**
     * 查询投诉模板
     *
     * @param id 投诉模板主键
     * @return 投诉模板
     */
    FsComplaintTemplate selectFsComplaintTemplateById(Long id);

    /**
     * 查询投诉模板列表
     *
     * @param fsComplaintTemplate 投诉模板
     * @return 投诉模板集合
     */
    List<FsComplaintTemplate> selectFsComplaintTemplateList(FsComplaintTemplate fsComplaintTemplate);

    /**
     * 新增投诉模板
     *
     * @param fsComplaintTemplate 投诉模板
     * @return 结果
     */
    int insertFsComplaintTemplate(FsComplaintTemplate fsComplaintTemplate);

    /**
     * 修改投诉模板
     *
     * @param fsComplaintTemplate 投诉模板
     * @return 结果
     */
    int updateFsComplaintTemplate(FsComplaintTemplate fsComplaintTemplate);

    /**
     * 批量删除投诉模板
     *
     * @param ids 需要删除的投诉模板主键集合
     * @return 结果
     */
    int deleteFsComplaintTemplateByIds(Long[] ids);

    /**
     * 删除投诉模板信息
     *
     * @param id 投诉模板主键
     * @return 结果
     */
    int deleteFsComplaintTemplateById(Long id);
}
